@@ -3,8 +3,8 @@
 
 __modules__ = ['ROA']
 #import ROA
-from ROA.ROA import RunningOptimalAverage
+from ROA import RunningOptimalAverage
 
-__version__ = "1.1"
+__version__ = "1.2"
 
 
